package com.github.wxiaoqi.security.admin.rest;

import com.github.wxiaoqi.security.admin.biz.AppStaffUserBiz;
import com.github.wxiaoqi.security.admin.entity.AppStaffUser;
import com.github.wxiaoqi.security.admin.feign.dto.AppUserDTO;
import com.github.wxiaoqi.security.auth.client.config.UserAuthConfig;
import com.github.wxiaoqi.security.common.exception.BaseException;
import com.github.wxiaoqi.security.common.msg.ObjectRestResponse;
import com.github.wxiaoqi.security.common.rest.BaseController;
import com.github.wxiaoqi.security.common.util.process.ResultCode;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * @author Administrator
 */
@RestController
@RequestMapping("/staff")
@RequiredArgsConstructor(onConstructor_ = {@Autowired})
@Api(tags = {"员工客户管理"})
public class AppStaffUserController extends BaseController<AppStaffUserBiz, AppStaffUser> {
    private final UserAuthConfig authConfig;
    private final HttpServletRequest request;
    private final PublicController publicController;
    private final String POSITION_NAME="员工";

    /**
     * 获取该用户所用的客户
     * @return
     * @throws Exception
     */
    @GetMapping("/getAll")
    public  ObjectRestResponse<List<AppStaffUser>> getAll() throws Exception {
        AppUserDTO userDTO = (AppUserDTO) publicController.userDetailByToken(authConfig.getToken(request)).getData();
        if (POSITION_NAME.equals(userDTO.getPositionName())) {
         return ObjectRestResponse.succ(baseBiz.getAll(userDTO.getUserid())) ;
        }
     return ObjectRestResponse.succ();
    }

    @Override
    @ApiOperation("添加")
    @PostMapping(value = "")
    public ObjectRestResponse<AppStaffUser> add(@RequestBody AppStaffUser appStaffUser) throws Exception {
        AppUserDTO userDTO = (AppUserDTO) publicController.userDetailByToken(authConfig.getToken(request)).getData();
        if (appStaffUser.getPhone().equals(userDTO.getUsername())) {
           return ObjectRestResponse.createFailedResult(ResultCode.FAILED_CODE,"不能绑定本人为客户");
        }
        appStaffUser.setSuId(userDTO.getUserid());
        if (baseBiz.select(appStaffUser)) {
            baseBiz.insertSelective(appStaffUser);
            return  ObjectRestResponse.succ();
        }
        throw  new BaseException("客户已存在");

    }

    @ApiOperation("查询一条")
    @GetMapping(value = "one")
    public ObjectRestResponse<AppStaffUser> findOne(AppStaffUser appStaffUser)  {
        AppStaffUser staffUser = baseBiz.findOne(appStaffUser);

        if (staffUser!=null) {
            return ObjectRestResponse.succ(staffUser);
        }
        return ObjectRestResponse.succ();
    }

    @ApiOperation("删除")
    @DeleteMapping(value = "delete/{id}")
    public ObjectRestResponse<AppStaffUser> delete(@PathVariable Integer id)  {
        AppStaffUser staffUser = new AppStaffUser();
        staffUser.setId(id);
        staffUser.setIsDel(1);
        baseBiz.updateSelectiveById(staffUser);
        return ObjectRestResponse.succ();
    }

    @Override
    @ApiOperation("修改")
    @RequestMapping(value = "/{id}",method = RequestMethod.PUT)
    @ResponseBody
    public ObjectRestResponse update(@RequestBody AppStaffUser appStaffUser) throws Exception {
        AppUserDTO userDTO = (AppUserDTO) publicController.userDetailByToken(authConfig.getToken(request)).getData();
        if (appStaffUser.getPhone().equals(userDTO.getUsername())) {
            return ObjectRestResponse.createFailedResult(ResultCode.FAILED_CODE,"不能绑定本人为客户");
        }
        if (baseBiz.select(appStaffUser)) {
            baseBiz.updateSelectiveById(appStaffUser);
            return ObjectRestResponse.succ();
        }
        throw  new BaseException("客户已存在");
    }

}
